
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import error_codes_pb2 as tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/queue_runner.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x11QueueRunnerProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n+tensorflow/core/protobuf/queue_runner.proto\x12\ntensorflow\x1a*tensorflow/core/protobuf/error_codes.proto"\xaa\x01\n\x0eQueueRunnerDef\x12\x12\n\nqueue_name\x18\x01 \x01(\t\x12\x17\n\x0fenqueue_op_name\x18\x02 \x03(\t\x12\x15\n\rclose_op_name\x18\x03 \x01(\t\x12\x16\n\x0ecancel_op_name\x18\x04 \x01(\t\x12<\n\x1cqueue_closed_exception_types\x18\x05 \x03(\x0e2\x16.tensorflow.error.CodeB\x89\x01\n\x18org.tensorflow.frameworkB\x11QueueRunnerProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR])
_QUEUERUNNERDEF = _descriptor.Descriptor(name='QueueRunnerDef', full_name='tensorflow.QueueRunnerDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='queue_name', full_name='tensorflow.QueueRunnerDef.queue_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enqueue_op_name', full_name='tensorflow.QueueRunnerDef.enqueue_op_name', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='close_op_name', full_name='tensorflow.QueueRunnerDef.close_op_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cancel_op_name', full_name='tensorflow.QueueRunnerDef.cancel_op_name', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='queue_closed_exception_types', full_name='tensorflow.QueueRunnerDef.queue_closed_exception_types', index=4, number=5, type=14, cpp_type=8, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=104, serialized_end=274)
_QUEUERUNNERDEF.fields_by_name['queue_closed_exception_types'].enum_type = tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2._CODE
DESCRIPTOR.message_types_by_name['QueueRunnerDef'] = _QUEUERUNNERDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
QueueRunnerDef = _reflection.GeneratedProtocolMessageType('QueueRunnerDef', (_message.Message,), {'DESCRIPTOR': _QUEUERUNNERDEF, '__module__': 'tensorflow.core.protobuf.queue_runner_pb2'})
_sym_db.RegisterMessage(QueueRunnerDef)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/named_tensor.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x11NamedTensorProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n+tensorflow/core/protobuf/named_tensor.proto\x12\ntensorflow\x1a&tensorflow/core/framework/tensor.proto"I\n\x10NamedTensorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x06tensor\x18\x02 \x01(\x0b2\x17.tensorflow.TensorProtoB\x89\x01\n\x18org.tensorflow.frameworkB\x11NamedTensorProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR])
_NAMEDTENSORPROTO = _descriptor.Descriptor(name='NamedTensorProto', full_name='tensorflow.NamedTensorProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.NamedTensorProto.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.NamedTensorProto.tensor', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=99, serialized_end=172)
_NAMEDTENSORPROTO.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
DESCRIPTOR.message_types_by_name['NamedTensorProto'] = _NAMEDTENSORPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
NamedTensorProto = _reflection.GeneratedProtocolMessageType('NamedTensorProto', (_message.Message,), {'DESCRIPTOR': _NAMEDTENSORPROTO, '__module__': 'tensorflow.core.protobuf.named_tensor_pb2'})
_sym_db.RegisterMessage(NamedTensorProto)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import allocation_description_pb2 as tensorflow_dot_core_dot_framework_dot_allocation__description__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/tensor_description.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x17TensorDescriptionProtosP\x01ZYgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/tensor_description_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n2tensorflow/core/framework/tensor_description.proto\x12\ntensorflow\x1a6tensorflow/core/framework/allocation_description.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\xa8\x01\n\x11TensorDescription\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12A\n\x16allocation_description\x18\x04 \x01(\x0b2!.tensorflow.AllocationDescriptionB\x93\x01\n\x18org.tensorflow.frameworkB\x17TensorDescriptionProtosP\x01ZYgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/tensor_description_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_allocation__description__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_TENSORDESCRIPTION = _descriptor.Descriptor(name='TensorDescription', full_name='tensorflow.TensorDescription', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.TensorDescription.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.TensorDescription.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_description', full_name='tensorflow.TensorDescription.allocation_description', index=2, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=208, serialized_end=376)
_TENSORDESCRIPTION.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_TENSORDESCRIPTION.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TENSORDESCRIPTION.fields_by_name['allocation_description'].message_type = tensorflow_dot_core_dot_framework_dot_allocation__description__pb2._ALLOCATIONDESCRIPTION
DESCRIPTOR.message_types_by_name['TensorDescription'] = _TENSORDESCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorDescription = _reflection.GeneratedProtocolMessageType('TensorDescription', (_message.Message,), {'DESCRIPTOR': _TENSORDESCRIPTION, '__module__': 'tensorflow.core.framework.tensor_description_pb2'})
_sym_db.RegisterMessage(TensorDescription)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/resource_handle.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0eResourceHandleP\x01ZVgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/resource_handle_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n/tensorflow/core/framework/resource_handle.proto\x12\ntensorflow\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\xa5\x02\n\x13ResourceHandleProto\x12\x0e\n\x06device\x18\x01 \x01(\t\x12\x11\n\tcontainer\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\thash_code\x18\x04 \x01(\x04\x12\x17\n\x0fmaybe_type_name\x18\x05 \x01(\t\x12H\n\x11dtypes_and_shapes\x18\x06 \x03(\x0b2-.tensorflow.ResourceHandleProto.DtypeAndShape\x1aa\n\rDtypeAndShape\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProtoJ\x04\x08\x07\x10\x08B\x87\x01\n\x18org.tensorflow.frameworkB\x0eResourceHandleP\x01ZVgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/resource_handle_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_RESOURCEHANDLEPROTO_DTYPEANDSHAPE = _descriptor.Descriptor(name='DtypeAndShape', full_name='tensorflow.ResourceHandleProto.DtypeAndShape', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.ResourceHandleProto.DtypeAndShape.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.ResourceHandleProto.DtypeAndShape.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=339, serialized_end=436)
_RESOURCEHANDLEPROTO = _descriptor.Descriptor(name='ResourceHandleProto', full_name='tensorflow.ResourceHandleProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device', full_name='tensorflow.ResourceHandleProto.device', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='container', full_name='tensorflow.ResourceHandleProto.container', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.ResourceHandleProto.name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hash_code', full_name='tensorflow.ResourceHandleProto.hash_code', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='maybe_type_name', full_name='tensorflow.ResourceHandleProto.maybe_type_name', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtypes_and_shapes', full_name='tensorflow.ResourceHandleProto.dtypes_and_shapes', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_RESOURCEHANDLEPROTO_DTYPEANDSHAPE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=149, serialized_end=442)
_RESOURCEHANDLEPROTO_DTYPEANDSHAPE.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_RESOURCEHANDLEPROTO_DTYPEANDSHAPE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_RESOURCEHANDLEPROTO_DTYPEANDSHAPE.containing_type = _RESOURCEHANDLEPROTO
_RESOURCEHANDLEPROTO.fields_by_name['dtypes_and_shapes'].message_type = _RESOURCEHANDLEPROTO_DTYPEANDSHAPE
DESCRIPTOR.message_types_by_name['ResourceHandleProto'] = _RESOURCEHANDLEPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ResourceHandleProto = _reflection.GeneratedProtocolMessageType('ResourceHandleProto', (_message.Message,), {'DtypeAndShape': _reflection.GeneratedProtocolMessageType('DtypeAndShape', (_message.Message,), {'DESCRIPTOR': _RESOURCEHANDLEPROTO_DTYPEANDSHAPE, '__module__': 'tensorflow.core.framework.resource_handle_pb2'}), 'DESCRIPTOR': _RESOURCEHANDLEPROTO, '__module__': 'tensorflow.core.framework.resource_handle_pb2'})
_sym_db.RegisterMessage(ResourceHandleProto)
_sym_db.RegisterMessage(ResourceHandleProto.DtypeAndShape)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
from .....tensorflow.core.profiler.protobuf import kernel_stats_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_kernel__stats__pb2
from .....tensorflow.core.profiler.protobuf import op_metrics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2
from .....tensorflow.core.profiler.protobuf import steps_db_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_steps__db__pb2
from .....tensorflow.core.profiler.protobuf import tf_function_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_tf__function__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/op_stats.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n0tensorflow/core/profiler/protobuf/op_stats.proto\x12\x13tensorflow.profiler\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto\x1a4tensorflow/core/profiler/protobuf/kernel_stats.proto\x1a2tensorflow/core/profiler/protobuf/op_metrics.proto\x1a0tensorflow/core/profiler/protobuf/steps_db.proto\x1a3tensorflow/core/profiler/protobuf/tf_function.proto"m\n\x07PerfEnv\x12"\n\x1apeak_tera_flops_per_second\x18\x01 \x01(\x01\x12)\n!peak_hbm_bw_giga_bytes_per_second\x18\x02 \x01(\x01\x12\x13\n\x0bridge_point\x18\x03 \x01(\x01"z\n\x1cHostIndependentJobInfoResult\x12\x13\n\x0bchange_list\x18\x01 \x01(\x03\x12\x12\n\nbuild_time\x18\x02 \x01(\x03\x12\x14\n\x0cbuild_target\x18\x03 \x01(\t\x12\x1b\n\x13profile_duration_ms\x18\x04 \x01(\r"\x85\x01\n\x1aHostDependentJobInfoResult\x12\x0f\n\x07host_id\x18\x01 \x01(\t\x12\x14\n\x0ccommand_line\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x13\n\x0bbns_address\x18\x04 \x01(\t\x12\x17\n\x0fprofile_time_ns\x18\x05 \x01(\x04"s\n\x0eSystemTopology\x12\x13\n\x0bx_dimension\x18\x01 \x01(\x03\x12\x13\n\x0by_dimension\x18\x02 \x01(\x03\x12\x13\n\x0bz_dimension\x18\x03 \x01(\x03\x12"\n\x1anum_expected_reduced_chips\x18\x04 \x01(\x03"\xad\x04\n\x0eRunEnvironment\x12\x12\n\nhost_count\x18\x01 \x01(\x05\x12\x12\n\ntask_count\x18\x02 \x01(\x05\x12E\n\thostnames\x18\x03 \x03(\x0b22.tensorflow.profiler.RunEnvironment.HostnamesEntry\x12\x13\n\x0bdevice_type\x18\x04 \x01(\t\x12\x19\n\x11device_core_count\x18\x05 \x01(\x05\x12\x1b\n\x13per_core_batch_size\x18\x06 \x01(\x05\x12T\n\x19host_independent_job_info\x18\x07 \x01(\x0b21.tensorflow.profiler.HostIndependentJobInfoResult\x12P\n\x17host_dependent_job_info\x18\x08 \x03(\x0b2/.tensorflow.profiler.HostDependentJobInfoResult\x12\x15\n\rreplica_count\x18\t \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\n \x01(\x05\x125\n\x08topology\x18\x0b \x01(\x0b2#.tensorflow.profiler.SystemTopology\x12\x18\n\x10host_trace_level\x18\x0c \x01(\r\x1a0\n\x0eHostnamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x028\x01"\x90\x01\n\x0bCoreDetails\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x16\n\x0edevice_ordinal\x18\x02 \x01(\r\x12\x10\n\x08core_num\x18\x03 \x01(\r\x12\x15\n\rlocal_chip_id\x18\x04 \x01(\r\x12\x16\n\x0eglobal_chip_id\x18\x05 \x01(\r\x12\x16\n\x0eglobal_core_id\x18\x06 \x01(\r"\xdb\x05\n\x07OpStats\x12<\n\x12host_op_metrics_db\x18\x01 \x01(\x0b2 .tensorflow.profiler.OpMetricsDb\x12>\n\x14device_op_metrics_db\x18\x02 \x01(\x0b2 .tensorflow.profiler.OpMetricsDb\x12L\n"hlo_metrics_db_complete_steps_only\x18\n \x01(\x0b2 .tensorflow.profiler.OpMetricsDb\x12.\n\x08perf_env\x18\x03 \x01(\x0b2\x1c.tensorflow.profiler.PerfEnv\x128\n\x07step_db\x18\x04 \x01(\x0b2\'.tensorflow.profiler.StepDatabaseResult\x12<\n\x0frun_environment\x18\x05 \x01(\x0b2#.tensorflow.profiler.RunEnvironment\x12;\n\x0fkernel_stats_db\x18\x06 \x01(\x0b2".tensorflow.profiler.KernelStatsDb\x129\n\x0etf_function_db\x18\x08 \x01(\x0b2!.tensorflow.profiler.TfFunctionDb\x12M\n\x12core_id_to_details\x18\x0b \x03(\x0b21.tensorflow.profiler.OpStats.CoreIdToDetailsEntry\x125\n\x0bdiagnostics\x18\t \x01(\x0b2 .tensorflow.profiler.Diagnostics\x1aX\n\x14CoreIdToDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12/\n\x05value\x18\x02 \x01(\x0b2 .tensorflow.profiler.CoreDetails:\x028\x01J\x04\x08\x07\x10\x08b\x06proto3', dependencies=[tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_kernel__stats__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_steps__db__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_tf__function__pb2.DESCRIPTOR])
_PERFENV = _descriptor.Descriptor(name='PerfEnv', full_name='tensorflow.profiler.PerfEnv', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='peak_tera_flops_per_second', full_name='tensorflow.profiler.PerfEnv.peak_tera_flops_per_second', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_hbm_bw_giga_bytes_per_second', full_name='tensorflow.profiler.PerfEnv.peak_hbm_bw_giga_bytes_per_second', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ridge_point', full_name='tensorflow.profiler.PerfEnv.ridge_point', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=335, serialized_end=444)
_HOSTINDEPENDENTJOBINFORESULT = _descriptor.Descriptor(name='HostIndependentJobInfoResult', full_name='tensorflow.profiler.HostIndependentJobInfoResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='change_list', full_name='tensorflow.profiler.HostIndependentJobInfoResult.change_list', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_time', full_name='tensorflow.profiler.HostIndependentJobInfoResult.build_time', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_target', full_name='tensorflow.profiler.HostIndependentJobInfoResult.build_target', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_duration_ms', full_name='tensorflow.profiler.HostIndependentJobInfoResult.profile_duration_ms', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=446, serialized_end=568)
_HOSTDEPENDENTJOBINFORESULT = _descriptor.Descriptor(name='HostDependentJobInfoResult', full_name='tensorflow.profiler.HostDependentJobInfoResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_id', full_name='tensorflow.profiler.HostDependentJobInfoResult.host_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='command_line', full_name='tensorflow.profiler.HostDependentJobInfoResult.command_line', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time', full_name='tensorflow.profiler.HostDependentJobInfoResult.start_time', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bns_address', full_name='tensorflow.profiler.HostDependentJobInfoResult.bns_address', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_time_ns', full_name='tensorflow.profiler.HostDependentJobInfoResult.profile_time_ns', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=571, serialized_end=704)
_SYSTEMTOPOLOGY = _descriptor.Descriptor(name='SystemTopology', full_name='tensorflow.profiler.SystemTopology', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='x_dimension', full_name='tensorflow.profiler.SystemTopology.x_dimension', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='y_dimension', full_name='tensorflow.profiler.SystemTopology.y_dimension', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='z_dimension', full_name='tensorflow.profiler.SystemTopology.z_dimension', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_expected_reduced_chips', full_name='tensorflow.profiler.SystemTopology.num_expected_reduced_chips', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=706, serialized_end=821)
_RUNENVIRONMENT_HOSTNAMESENTRY = _descriptor.Descriptor(name='HostnamesEntry', full_name='tensorflow.profiler.RunEnvironment.HostnamesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.RunEnvironment.HostnamesEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.RunEnvironment.HostnamesEntry.value', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1333, serialized_end=1381)
_RUNENVIRONMENT = _descriptor.Descriptor(name='RunEnvironment', full_name='tensorflow.profiler.RunEnvironment', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_count', full_name='tensorflow.profiler.RunEnvironment.host_count', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_count', full_name='tensorflow.profiler.RunEnvironment.task_count', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hostnames', full_name='tensorflow.profiler.RunEnvironment.hostnames', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.profiler.RunEnvironment.device_type', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_core_count', full_name='tensorflow.profiler.RunEnvironment.device_core_count', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='per_core_batch_size', full_name='tensorflow.profiler.RunEnvironment.per_core_batch_size', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_independent_job_info', full_name='tensorflow.profiler.RunEnvironment.host_independent_job_info', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_dependent_job_info', full_name='tensorflow.profiler.RunEnvironment.host_dependent_job_info', index=7, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='replica_count', full_name='tensorflow.profiler.RunEnvironment.replica_count', index=8, number=9, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='tensorflow.profiler.RunEnvironment.num_cores_per_replica', index=9, number=10, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='topology', full_name='tensorflow.profiler.RunEnvironment.topology', index=10, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_trace_level', full_name='tensorflow.profiler.RunEnvironment.host_trace_level', index=11, number=12, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_RUNENVIRONMENT_HOSTNAMESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=824, serialized_end=1381)
_COREDETAILS = _descriptor.Descriptor(name='CoreDetails', full_name='tensorflow.profiler.CoreDetails', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hostname', full_name='tensorflow.profiler.CoreDetails.hostname', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_ordinal', full_name='tensorflow.profiler.CoreDetails.device_ordinal', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_num', full_name='tensorflow.profiler.CoreDetails.core_num', index=2, number=3, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='local_chip_id', full_name='tensorflow.profiler.CoreDetails.local_chip_id', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='global_chip_id', full_name='tensorflow.profiler.CoreDetails.global_chip_id', index=4, number=5, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='global_core_id', full_name='tensorflow.profiler.CoreDetails.global_core_id', index=5, number=6, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1384, serialized_end=1528)
_OPSTATS_COREIDTODETAILSENTRY = _descriptor.Descriptor(name='CoreIdToDetailsEntry', full_name='tensorflow.profiler.OpStats.CoreIdToDetailsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.OpStats.CoreIdToDetailsEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.OpStats.CoreIdToDetailsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2168, serialized_end=2256)
_OPSTATS = _descriptor.Descriptor(name='OpStats', full_name='tensorflow.profiler.OpStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_op_metrics_db', full_name='tensorflow.profiler.OpStats.host_op_metrics_db', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_op_metrics_db', full_name='tensorflow.profiler.OpStats.device_op_metrics_db', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_metrics_db_complete_steps_only', full_name='tensorflow.profiler.OpStats.hlo_metrics_db_complete_steps_only', index=2, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='perf_env', full_name='tensorflow.profiler.OpStats.perf_env', index=3, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_db', full_name='tensorflow.profiler.OpStats.step_db', index=4, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_environment', full_name='tensorflow.profiler.OpStats.run_environment', index=5, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_stats_db', full_name='tensorflow.profiler.OpStats.kernel_stats_db', index=6, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_function_db', full_name='tensorflow.profiler.OpStats.tf_function_db', index=7, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_id_to_details', full_name='tensorflow.profiler.OpStats.core_id_to_details', index=8, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.OpStats.diagnostics', index=9, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_OPSTATS_COREIDTODETAILSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1531, serialized_end=2262)
_RUNENVIRONMENT_HOSTNAMESENTRY.containing_type = _RUNENVIRONMENT
_RUNENVIRONMENT.fields_by_name['hostnames'].message_type = _RUNENVIRONMENT_HOSTNAMESENTRY
_RUNENVIRONMENT.fields_by_name['host_independent_job_info'].message_type = _HOSTINDEPENDENTJOBINFORESULT
_RUNENVIRONMENT.fields_by_name['host_dependent_job_info'].message_type = _HOSTDEPENDENTJOBINFORESULT
_RUNENVIRONMENT.fields_by_name['topology'].message_type = _SYSTEMTOPOLOGY
_OPSTATS_COREIDTODETAILSENTRY.fields_by_name['value'].message_type = _COREDETAILS
_OPSTATS_COREIDTODETAILSENTRY.containing_type = _OPSTATS
_OPSTATS.fields_by_name['host_op_metrics_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2._OPMETRICSDB
_OPSTATS.fields_by_name['device_op_metrics_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2._OPMETRICSDB
_OPSTATS.fields_by_name['hlo_metrics_db_complete_steps_only'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2._OPMETRICSDB
_OPSTATS.fields_by_name['perf_env'].message_type = _PERFENV
_OPSTATS.fields_by_name['step_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_steps__db__pb2._STEPDATABASERESULT
_OPSTATS.fields_by_name['run_environment'].message_type = _RUNENVIRONMENT
_OPSTATS.fields_by_name['kernel_stats_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_kernel__stats__pb2._KERNELSTATSDB
_OPSTATS.fields_by_name['tf_function_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_tf__function__pb2._TFFUNCTIONDB
_OPSTATS.fields_by_name['core_id_to_details'].message_type = _OPSTATS_COREIDTODETAILSENTRY
_OPSTATS.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
DESCRIPTOR.message_types_by_name['PerfEnv'] = _PERFENV
DESCRIPTOR.message_types_by_name['HostIndependentJobInfoResult'] = _HOSTINDEPENDENTJOBINFORESULT
DESCRIPTOR.message_types_by_name['HostDependentJobInfoResult'] = _HOSTDEPENDENTJOBINFORESULT
DESCRIPTOR.message_types_by_name['SystemTopology'] = _SYSTEMTOPOLOGY
DESCRIPTOR.message_types_by_name['RunEnvironment'] = _RUNENVIRONMENT
DESCRIPTOR.message_types_by_name['CoreDetails'] = _COREDETAILS
DESCRIPTOR.message_types_by_name['OpStats'] = _OPSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
PerfEnv = _reflection.GeneratedProtocolMessageType('PerfEnv', (_message.Message,), {'DESCRIPTOR': _PERFENV, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(PerfEnv)
HostIndependentJobInfoResult = _reflection.GeneratedProtocolMessageType('HostIndependentJobInfoResult', (_message.Message,), {'DESCRIPTOR': _HOSTINDEPENDENTJOBINFORESULT, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(HostIndependentJobInfoResult)
HostDependentJobInfoResult = _reflection.GeneratedProtocolMessageType('HostDependentJobInfoResult', (_message.Message,), {'DESCRIPTOR': _HOSTDEPENDENTJOBINFORESULT, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(HostDependentJobInfoResult)
SystemTopology = _reflection.GeneratedProtocolMessageType('SystemTopology', (_message.Message,), {'DESCRIPTOR': _SYSTEMTOPOLOGY, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(SystemTopology)
RunEnvironment = _reflection.GeneratedProtocolMessageType('RunEnvironment', (_message.Message,), {'HostnamesEntry': _reflection.GeneratedProtocolMessageType('HostnamesEntry', (_message.Message,), {'DESCRIPTOR': _RUNENVIRONMENT_HOSTNAMESENTRY, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'}), 'DESCRIPTOR': _RUNENVIRONMENT, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(RunEnvironment)
_sym_db.RegisterMessage(RunEnvironment.HostnamesEntry)
CoreDetails = _reflection.GeneratedProtocolMessageType('CoreDetails', (_message.Message,), {'DESCRIPTOR': _COREDETAILS, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(CoreDetails)
OpStats = _reflection.GeneratedProtocolMessageType('OpStats', (_message.Message,), {'CoreIdToDetailsEntry': _reflection.GeneratedProtocolMessageType('CoreIdToDetailsEntry', (_message.Message,), {'DESCRIPTOR': _OPSTATS_COREIDTODETAILSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'}), 'DESCRIPTOR': _OPSTATS, '__module__': 'tensorflow.core.profiler.protobuf.op_stats_pb2'})
_sym_db.RegisterMessage(OpStats)
_sym_db.RegisterMessage(OpStats.CoreIdToDetailsEntry)
_RUNENVIRONMENT_HOSTNAMESENTRY._options = None
_OPSTATS_COREIDTODETAILSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.protobuf.tpu import optimization_parameters_pb2 as tensorflow_dot_core_dot_protobuf_dot_tpu_dot_optimization__parameters__pb2
from .....tensorflow.core.protobuf.tpu import tpu_embedding_output_layout_pb2 as tensorflow_dot_core_dot_protobuf_dot_tpu_dot_tpu__embedding__output__layout__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/tpu_embedding_configuration.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n>tensorflow/core/protobuf/tpu/tpu_embedding_configuration.proto\x12\x0etensorflow.tpu\x1a:tensorflow/core/protobuf/tpu/optimization_parameters.proto\x1a>tensorflow/core/protobuf/tpu/tpu_embedding_output_layout.proto"\x91\x06\n\x19TPUEmbeddingConfiguration\x12S\n\x10table_descriptor\x18\x01 \x03(\x0b29.tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor\x12<\n\x04mode\x18\x02 \x01(\x0e2..tensorflow.tpu.TPUEmbeddingConfiguration.Mode\x12"\n\x1abatch_size_per_tensor_core\x18\x03 \x01(\x05\x12\x11\n\tnum_hosts\x18\x04 \x01(\x05\x12\x18\n\x10num_tensor_cores\x18\x05 \x01(\x05\x12U\n\x11sharding_strategy\x18\x06 \x01(\x0e2:.tensorflow.tpu.TPUEmbeddingConfiguration.ShardingStrategy\x12+\n#pipeline_execution_with_tensor_core\x18\x07 \x01(\x08\x12\x1e\n\x16profile_data_directory\x18\t \x01(\t\x12C\n\routput_layout\x18\x08 \x01(\x0b2(.tensorflow.tpu.TPUEmbeddingOutputLayoutB\x02\x18\x01\x1a\xaa\x01\n\x0fTableDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fvocabulary_size\x18\x02 \x01(\x03\x12\x11\n\tdimension\x18\x03 \x01(\x05\x12\x14\n\x0cnum_features\x18\x04 \x01(\x05\x12G\n\x17optimization_parameters\x18\x05 \x01(\x0b2&.tensorflow.tpu.OptimizationParameters"L\n\x04Mode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tINFERENCE\x10\x01\x12\x0c\n\x08TRAINING\x10\x02\x12\x16\n\x12BACKWARD_PASS_ONLY\x10\x03",\n\x10ShardingStrategy\x12\x0f\n\x0bDIV_DEFAULT\x10\x00\x12\x07\n\x03MOD\x10\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_tpu_dot_optimization__parameters__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tpu_dot_tpu__embedding__output__layout__pb2.DESCRIPTOR])
_TPUEMBEDDINGCONFIGURATION_MODE = _descriptor.EnumDescriptor(name='Mode', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.Mode', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNSPECIFIED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INFERENCE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TRAINING', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BACKWARD_PASS_ONLY', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=870, serialized_end=946)
_sym_db.RegisterEnumDescriptor(_TPUEMBEDDINGCONFIGURATION_MODE)
_TPUEMBEDDINGCONFIGURATION_SHARDINGSTRATEGY = _descriptor.EnumDescriptor(name='ShardingStrategy', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.ShardingStrategy', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DIV_DEFAULT', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='MOD', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=948, serialized_end=992)
_sym_db.RegisterEnumDescriptor(_TPUEMBEDDINGCONFIGURATION_SHARDINGSTRATEGY)
_TPUEMBEDDINGCONFIGURATION_TABLEDESCRIPTOR = _descriptor.Descriptor(name='TableDescriptor', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='vocabulary_size', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor.vocabulary_size', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dimension', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor.dimension', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_features', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor.num_features', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='optimization_parameters', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.TableDescriptor.optimization_parameters', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=698, serialized_end=868)
_TPUEMBEDDINGCONFIGURATION = _descriptor.Descriptor(name='TPUEmbeddingConfiguration', full_name='tensorflow.tpu.TPUEmbeddingConfiguration', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='table_descriptor', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.table_descriptor', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mode', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.mode', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='batch_size_per_tensor_core', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.batch_size_per_tensor_core', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_hosts', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.num_hosts', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_tensor_cores', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.num_tensor_cores', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sharding_strategy', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.sharding_strategy', index=5, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pipeline_execution_with_tensor_core', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.pipeline_execution_with_tensor_core', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_data_directory', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.profile_data_directory', index=7, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_layout', full_name='tensorflow.tpu.TPUEmbeddingConfiguration.output_layout', index=8, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUEMBEDDINGCONFIGURATION_TABLEDESCRIPTOR], enum_types=[_TPUEMBEDDINGCONFIGURATION_MODE, _TPUEMBEDDINGCONFIGURATION_SHARDINGSTRATEGY], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=207, serialized_end=992)
_TPUEMBEDDINGCONFIGURATION_TABLEDESCRIPTOR.fields_by_name['optimization_parameters'].message_type = tensorflow_dot_core_dot_protobuf_dot_tpu_dot_optimization__parameters__pb2._OPTIMIZATIONPARAMETERS
_TPUEMBEDDINGCONFIGURATION_TABLEDESCRIPTOR.containing_type = _TPUEMBEDDINGCONFIGURATION
_TPUEMBEDDINGCONFIGURATION.fields_by_name['table_descriptor'].message_type = _TPUEMBEDDINGCONFIGURATION_TABLEDESCRIPTOR
_TPUEMBEDDINGCONFIGURATION.fields_by_name['mode'].enum_type = _TPUEMBEDDINGCONFIGURATION_MODE
_TPUEMBEDDINGCONFIGURATION.fields_by_name['sharding_strategy'].enum_type = _TPUEMBEDDINGCONFIGURATION_SHARDINGSTRATEGY
_TPUEMBEDDINGCONFIGURATION.fields_by_name['output_layout'].message_type = tensorflow_dot_core_dot_protobuf_dot_tpu_dot_tpu__embedding__output__layout__pb2._TPUEMBEDDINGOUTPUTLAYOUT
_TPUEMBEDDINGCONFIGURATION_MODE.containing_type = _TPUEMBEDDINGCONFIGURATION
_TPUEMBEDDINGCONFIGURATION_SHARDINGSTRATEGY.containing_type = _TPUEMBEDDINGCONFIGURATION
DESCRIPTOR.message_types_by_name['TPUEmbeddingConfiguration'] = _TPUEMBEDDINGCONFIGURATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TPUEmbeddingConfiguration = _reflection.GeneratedProtocolMessageType('TPUEmbeddingConfiguration', (_message.Message,), {'TableDescriptor': _reflection.GeneratedProtocolMessageType('TableDescriptor', (_message.Message,), {'DESCRIPTOR': _TPUEMBEDDINGCONFIGURATION_TABLEDESCRIPTOR, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_configuration_pb2'}), 'DESCRIPTOR': _TPUEMBEDDINGCONFIGURATION, '__module__': 'tensorflow.core.protobuf.tpu.tpu_embedding_configuration_pb2'})
_sym_db.RegisterMessage(TPUEmbeddingConfiguration)
_sym_db.RegisterMessage(TPUEmbeddingConfiguration.TableDescriptor)
_TPUEMBEDDINGCONFIGURATION.fields_by_name['output_layout']._options = None



from __future__ import annotations

from typing import ClassVar, Dict, Any, Mapping

# /* Copyright 2018 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================*/
# #ifndef TENSORFLOW_PYTHON_LIB_CORE_PY_EXCEPTION_REGISTRY_H_
# #define TENSORFLOW_PYTHON_LIB_CORE_PY_EXCEPTION_REGISTRY_H_
#
# #include <Python.h>
#
# #include <map>
#
# #include "tensorflow/c/tf_status.h"
# #include "tensorflow/core/lib/core/error_codes.pb.h"
#
# namespace tensorflow {
#
# // Global registry mapping C API error codes to the corresponding custom Python
# // exception type. This is used to expose the exception types to C extension
# // code (i.e. so we can raise custom exceptions via SWIG).
# //
# // Init() must be called exactly once at the beginning of the process before
# // Lookup() can be used.
# //
# // Example usage:
# //   TF_Status* status = TF_NewStatus();
# //   TF_Foo(..., status);
# //
# //   if (TF_GetCode(status) != TF_OK) {
# //     PyObject* exc_type = PyExceptionRegistry::Lookup(TF_GetCode(status));
# //     // Arguments to OpError base class. Set `node_def` and `op` to None.
# //     PyObject* args =
# //       Py_BuildValue("sss", nullptr, nullptr, TF_Message(status));
# //     PyErr_SetObject(exc_type, args);
# //     Py_DECREF(args);
# //     TF_DeleteStatus(status);
# //     return NULL;
# //   }
# class PyExceptionRegistry {
#  public:
#   // Initializes the process-wide registry. Should be called exactly once near
#   // the beginning of the process. The arguments are the various Python
#   // exception types (e.g. `cancelled_exc` corresponds to
#   // errors.CancelledError).
#   static void Init(PyObject* code_to_exc_type_map);
#
#   // Returns the Python exception type corresponding to `code`. Init() must be
#   // called before using this function. `code` should not be TF_OK.
#   static PyObject* Lookup(TF_Code code);
#
#   static inline PyObject* Lookup(error::Code code) {
#     return Lookup(static_cast<TF_Code>(code));
#   }
#
#  private:
#   static PyExceptionRegistry* singleton_;
#   PyExceptionRegistry() = default;
#
#   // Maps error codes to the corresponding Python exception type.
#   std::map<TF_Code, PyObject*> exc_types_;
# };
#
# }  // namespace tensorflow
#
# #endif  // TENSORFLOW_PYTHON_LIB_CORE_PY_EXCEPTION_REGISTRY_H_

# /* Copyright 2018 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================*/
#
# #include "tensorflow/python/lib/core/py_exception_registry.h"
#
# #include <Python.h>
#
# #include "tensorflow/core/platform/logging.h"
# #include "tensorflow/core/protobuf/error_codes.pb.h"
#
# namespace tensorflow {
#
# PyExceptionRegistry* PyExceptionRegistry::singleton_ = nullptr;
#
# void PyExceptionRegistry::Init(PyObject* code_to_exc_type_map) {
#   CHECK(singleton_ == nullptr) << "PyExceptionRegistry::Init() already called";
#   singleton_ = new PyExceptionRegistry;
#
#   CHECK(PyDict_Check(code_to_exc_type_map));
#   PyObject* key;
#   PyObject* value;
#   Py_ssize_t pos = 0;
#   while (PyDict_Next(code_to_exc_type_map, &pos, &key, &value)) {
#     singleton_->exc_types_.emplace(static_cast<TF_Code>(PyLong_AsLong(key)),
#                                    value);
#     // The exception classes should also have the lifetime of the process, but
#     // incref just in case.
#     Py_INCREF(value);
#   }
#
#   static const TF_Code kAllCodes[] = {TF_CANCELLED,
#                                       TF_UNKNOWN,
#                                       TF_INVALID_ARGUMENT,
#                                       TF_DEADLINE_EXCEEDED,
#                                       TF_NOT_FOUND,
#                                       TF_ALREADY_EXISTS,
#                                       TF_PERMISSION_DENIED,
#                                       TF_UNAUTHENTICATED,
#                                       TF_RESOURCE_EXHAUSTED,
#                                       TF_FAILED_PRECONDITION,
#                                       TF_ABORTED,
#                                       TF_OUT_OF_RANGE,
#                                       TF_UNIMPLEMENTED,
#                                       TF_INTERNAL,
#                                       TF_UNAVAILABLE,
#                                       TF_DATA_LOSS};
#   for (TF_Code code : kAllCodes) {
#     CHECK(singleton_->exc_types_.find(code) != singleton_->exc_types_.end())
#         << error::Code_Name(static_cast<error::Code>(code))
#         << " is not registered";
#   }
# }
#
# PyObject* PyExceptionRegistry::Lookup(TF_Code code) {
#   CHECK(singleton_ != nullptr) << "Must call PyExceptionRegistry::Init() "
#                                   "before PyExceptionRegistry::Lookup()";
#   CHECK_NE(code, TF_OK);
#   auto it = singleton_->exc_types_.find(code);
#   CHECK(it != singleton_->exc_types_.end())
#       << "Unknown error code passed to PyExceptionRegistry::Lookup: " << code;
#   return it->second;
# }
#
# }  // namespace tensorflow

class PyExceptionRegistry:
  singleton_: ClassVar[PyExceptionRegistry] = None

  # std::map<TF_Code, PyObject*> exc_types_;
  exc_types_: Dict[int, Any]

  def __init__(self):
    self.exc_types_ = {}

  # static void Init(PyObject* code_to_exc_type_map);
  @classmethod
  def Init(cls, code_to_exc_type_map: Mapping):
    """Initializes the process-wide registry. Should be called exactly once near
    the beginning of the process. The arguments are the various Python
    exception types (e.g. `cancelled_exc` corresponds to
    errors.CancelledError).
    """
    # CHECK(singleton_ == nullptr) << "PyExceptionRegistry::Init() already called";
    assert cls.singleton_ is None, "PyExceptionRegistry::Init() already called"
    # singleton_ = new PyExceptionRegistry;
    cls.singleton_ = cls()
    #
    # CHECK(PyDict_Check(code_to_exc_type_map));
    # PyObject* key;
    # PyObject* value;
    # Py_ssize_t pos = 0;
    # while (PyDict_Next(code_to_exc_type_map, &pos, &key, &value)) {
    #   singleton_->exc_types_.emplace(static_cast<TF_Code>(PyLong_AsLong(key)),
    #                                  value);
    #   // The exception classes should also have the lifetime of the process, but
    #   // incref just in case.
    #   Py_INCREF(value);
    # }
    for key, value in code_to_exc_type_map.items():
      cls.singleton_.exc_types_[key] = value

    # static const TF_Code kAllCodes[] = {TF_CANCELLED,
    #                                     TF_UNKNOWN,
    #                                     TF_INVALID_ARGUMENT,
    #                                     TF_DEADLINE_EXCEEDED,
    #                                     TF_NOT_FOUND,
    #                                     TF_ALREADY_EXISTS,
    #                                     TF_PERMISSION_DENIED,
    #                                     TF_UNAUTHENTICATED,
    #                                     TF_RESOURCE_EXHAUSTED,
    #                                     TF_FAILED_PRECONDITION,
    #                                     TF_ABORTED,
    #                                     TF_OUT_OF_RANGE,
    #                                     TF_UNIMPLEMENTED,
    #                                     TF_INTERNAL,
    #                                     TF_UNAVAILABLE,
    #                                     TF_DATA_LOSS};
    # for (TF_Code code : kAllCodes) {
    #   CHECK(singleton_->exc_types_.find(code) != singleton_->exc_types_.end())
    #       << error::Code_Name(static_cast<error::Code>(code))
    #       << " is not registered";
    # }
    for code in range(1, 16):
      if code not in cls.singleton_.exc_types_:
        raise RuntimeError(f"Error code {code} is not registered")

  #   static PyObject* Lookup(TF_Code code);
  @classmethod
  def Lookup(cls, code):
    """Returns the Python exception type corresponding to `code`. Init() must be
    called before using this function. `code` should not be TF_OK.
    """
    # CHECK(singleton_ != nullptr) << "Must call PyExceptionRegistry::Init() "
    #                                 "before PyExceptionRegistry::Lookup()";
    assert cls.singleton_ is not None, "Must call PyExceptionRegistry::Init() before PyExceptionRegistry::Lookup()"
    # CHECK_NE(code, TF_OK);
    assert code != 0
    # auto it = singleton_->exc_types_.find(code);
    it = cls.singleton_.exc_types_.get(code)
    # CHECK(it != singleton_->exc_types_.end())
    #     << "Unknown error code passed to PyExceptionRegistry::Lookup: " << code;
    assert it is not None, f"Unknown error code passed to PyExceptionRegistry::Lookup: {code}"
    # return it->second;
    return it




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/diagnostics.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n3tensorflow/core/profiler/protobuf/diagnostics.proto\x12\x13tensorflow.profiler"=\n\x0bDiagnostics\x12\x0c\n\x04info\x18\x01 \x03(\t\x12\x10\n\x08warnings\x18\x02 \x03(\t\x12\x0e\n\x06errors\x18\x03 \x03(\tb\x06proto3')
_DIAGNOSTICS = _descriptor.Descriptor(name='Diagnostics', full_name='tensorflow.profiler.Diagnostics', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='info', full_name='tensorflow.profiler.Diagnostics.info', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='warnings', full_name='tensorflow.profiler.Diagnostics.warnings', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='errors', full_name='tensorflow.profiler.Diagnostics.errors', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=76, serialized_end=137)
DESCRIPTOR.message_types_by_name['Diagnostics'] = _DIAGNOSTICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
Diagnostics = _reflection.GeneratedProtocolMessageType('Diagnostics', (_message.Message,), {'DESCRIPTOR': _DIAGNOSTICS, '__module__': 'tensorflow.core.profiler.protobuf.diagnostics_pb2'})
_sym_db.RegisterMessage(Diagnostics)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import allocation_description_pb2 as tensorflow_dot_core_dot_framework_dot_allocation__description__pb2
from ....tensorflow.core.framework import tensor_description_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__description__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/step_stats.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0fStepStatsProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/step_stats_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/framework/step_stats.proto\x12\ntensorflow\x1a6tensorflow/core/framework/allocation_description.proto\x1a2tensorflow/core/framework/tensor_description.proto"=\n\x10AllocationRecord\x12\x14\n\x0calloc_micros\x18\x01 \x01(\x03\x12\x13\n\x0balloc_bytes\x18\x02 \x01(\x03"\xc4\x01\n\x13AllocatorMemoryUsed\x12\x16\n\x0eallocator_name\x18\x01 \x01(\t\x12\x13\n\x0btotal_bytes\x18\x02 \x01(\x03\x12\x12\n\npeak_bytes\x18\x03 \x01(\x03\x12\x12\n\nlive_bytes\x18\x04 \x01(\x03\x128\n\x12allocation_records\x18\x06 \x03(\x0b2\x1c.tensorflow.AllocationRecord\x12\x1e\n\x16allocator_bytes_in_use\x18\x05 \x01(\x03"U\n\nNodeOutput\x12\x0c\n\x04slot\x18\x01 \x01(\x05\x129\n\x12tensor_description\x18\x03 \x01(\x0b2\x1d.tensorflow.TensorDescription"\xec\x01\n\x0bMemoryStats\x12\x18\n\x10temp_memory_size\x18\x01 \x01(\x03\x12\x1e\n\x16persistent_memory_size\x18\x03 \x01(\x03\x12#\n\x1bpersistent_tensor_alloc_ids\x18\x05 \x03(\x03\x12#\n\x17device_temp_memory_size\x18\x02 \x01(\x03B\x02\x18\x01\x12)\n\x1ddevice_persistent_memory_size\x18\x04 \x01(\x03B\x02\x18\x01\x12.\n"device_persistent_tensor_alloc_ids\x18\x06 \x03(\x03B\x02\x18\x01"\x9e\x04\n\rNodeExecStats\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x18\n\x10all_start_micros\x18\x02 \x01(\x03\x12\x1b\n\x13op_start_rel_micros\x18\x03 \x01(\x03\x12\x19\n\x11op_end_rel_micros\x18\x04 \x01(\x03\x12\x1a\n\x12all_end_rel_micros\x18\x05 \x01(\x03\x12/\n\x06memory\x18\x06 \x03(\x0b2\x1f.tensorflow.AllocatorMemoryUsed\x12&\n\x06output\x18\x07 \x03(\x0b2\x16.tensorflow.NodeOutput\x12\x16\n\x0etimeline_label\x18\x08 \x01(\t\x12\x18\n\x10scheduled_micros\x18\t \x01(\x03\x12\x11\n\tthread_id\x18\n \x01(\r\x12<\n\x11referenced_tensor\x18\x0b \x03(\x0b2!.tensorflow.AllocationDescription\x12-\n\x0cmemory_stats\x18\x0c \x01(\x0b2\x17.tensorflow.MemoryStats\x12\x17\n\x0fall_start_nanos\x18\r \x01(\x03\x12\x1a\n\x12op_start_rel_nanos\x18\x0e \x01(\x03\x12\x18\n\x10op_end_rel_nanos\x18\x0f \x01(\x03\x12\x19\n\x11all_end_rel_nanos\x18\x10 \x01(\x03\x12\x17\n\x0fscheduled_nanos\x18\x11 \x01(\x03"\xc8\x01\n\x0fDeviceStepStats\x12\x0e\n\x06device\x18\x01 \x01(\t\x12-\n\nnode_stats\x18\x02 \x03(\x0b2\x19.tensorflow.NodeExecStats\x12B\n\x0cthread_names\x18\x03 \x03(\x0b2,.tensorflow.DeviceStepStats.ThreadNamesEntry\x1a2\n\x10ThreadNamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01";\n\tStepStats\x12.\n\tdev_stats\x18\x01 \x03(\x0b2\x1b.tensorflow.DeviceStepStatsB\x83\x01\n\x18org.tensorflow.frameworkB\x0fStepStatsProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/step_stats_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_allocation__description__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__description__pb2.DESCRIPTOR])
_ALLOCATIONRECORD = _descriptor.Descriptor(name='AllocationRecord', full_name='tensorflow.AllocationRecord', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='alloc_micros', full_name='tensorflow.AllocationRecord.alloc_micros', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alloc_bytes', full_name='tensorflow.AllocationRecord.alloc_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=166, serialized_end=227)
_ALLOCATORMEMORYUSED = _descriptor.Descriptor(name='AllocatorMemoryUsed', full_name='tensorflow.AllocatorMemoryUsed', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='allocator_name', full_name='tensorflow.AllocatorMemoryUsed.allocator_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_bytes', full_name='tensorflow.AllocatorMemoryUsed.total_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_bytes', full_name='tensorflow.AllocatorMemoryUsed.peak_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='live_bytes', full_name='tensorflow.AllocatorMemoryUsed.live_bytes', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_records', full_name='tensorflow.AllocatorMemoryUsed.allocation_records', index=4, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocator_bytes_in_use', full_name='tensorflow.AllocatorMemoryUsed.allocator_bytes_in_use', index=5, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=230, serialized_end=426)
_NODEOUTPUT = _descriptor.Descriptor(name='NodeOutput', full_name='tensorflow.NodeOutput', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='slot', full_name='tensorflow.NodeOutput.slot', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_description', full_name='tensorflow.NodeOutput.tensor_description', index=1, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=428, serialized_end=513)
_MEMORYSTATS = _descriptor.Descriptor(name='MemoryStats', full_name='tensorflow.MemoryStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='temp_memory_size', full_name='tensorflow.MemoryStats.temp_memory_size', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='persistent_memory_size', full_name='tensorflow.MemoryStats.persistent_memory_size', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='persistent_tensor_alloc_ids', full_name='tensorflow.MemoryStats.persistent_tensor_alloc_ids', index=2, number=5, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_temp_memory_size', full_name='tensorflow.MemoryStats.device_temp_memory_size', index=3, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_persistent_memory_size', full_name='tensorflow.MemoryStats.device_persistent_memory_size', index=4, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_persistent_tensor_alloc_ids', full_name='tensorflow.MemoryStats.device_persistent_tensor_alloc_ids', index=5, number=6, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=516, serialized_end=752)
_NODEEXECSTATS = _descriptor.Descriptor(name='NodeExecStats', full_name='tensorflow.NodeExecStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_name', full_name='tensorflow.NodeExecStats.node_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_start_micros', full_name='tensorflow.NodeExecStats.all_start_micros', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_start_rel_micros', full_name='tensorflow.NodeExecStats.op_start_rel_micros', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_end_rel_micros', full_name='tensorflow.NodeExecStats.op_end_rel_micros', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_end_rel_micros', full_name='tensorflow.NodeExecStats.all_end_rel_micros', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory', full_name='tensorflow.NodeExecStats.memory', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output', full_name='tensorflow.NodeExecStats.output', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='timeline_label', full_name='tensorflow.NodeExecStats.timeline_label', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='scheduled_micros', full_name='tensorflow.NodeExecStats.scheduled_micros', index=8, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='thread_id', full_name='tensorflow.NodeExecStats.thread_id', index=9, number=10, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='referenced_tensor', full_name='tensorflow.NodeExecStats.referenced_tensor', index=10, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_stats', full_name='tensorflow.NodeExecStats.memory_stats', index=11, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_start_nanos', full_name='tensorflow.NodeExecStats.all_start_nanos', index=12, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_start_rel_nanos', full_name='tensorflow.NodeExecStats.op_start_rel_nanos', index=13, number=14, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_end_rel_nanos', full_name='tensorflow.NodeExecStats.op_end_rel_nanos', index=14, number=15, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_end_rel_nanos', full_name='tensorflow.NodeExecStats.all_end_rel_nanos', index=15, number=16, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='scheduled_nanos', full_name='tensorflow.NodeExecStats.scheduled_nanos', index=16, number=17, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=755, serialized_end=1297)
_DEVICESTEPSTATS_THREADNAMESENTRY = _descriptor.Descriptor(name='ThreadNamesEntry', full_name='tensorflow.DeviceStepStats.ThreadNamesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.DeviceStepStats.ThreadNamesEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.DeviceStepStats.ThreadNamesEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1450, serialized_end=1500)
_DEVICESTEPSTATS = _descriptor.Descriptor(name='DeviceStepStats', full_name='tensorflow.DeviceStepStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device', full_name='tensorflow.DeviceStepStats.device', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_stats', full_name='tensorflow.DeviceStepStats.node_stats', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='thread_names', full_name='tensorflow.DeviceStepStats.thread_names', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DEVICESTEPSTATS_THREADNAMESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1300, serialized_end=1500)
_STEPSTATS = _descriptor.Descriptor(name='StepStats', full_name='tensorflow.StepStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dev_stats', full_name='tensorflow.StepStats.dev_stats', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1502, serialized_end=1561)
_ALLOCATORMEMORYUSED.fields_by_name['allocation_records'].message_type = _ALLOCATIONRECORD
_NODEOUTPUT.fields_by_name['tensor_description'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__description__pb2._TENSORDESCRIPTION
_NODEEXECSTATS.fields_by_name['memory'].message_type = _ALLOCATORMEMORYUSED
_NODEEXECSTATS.fields_by_name['output'].message_type = _NODEOUTPUT
_NODEEXECSTATS.fields_by_name['referenced_tensor'].message_type = tensorflow_dot_core_dot_framework_dot_allocation__description__pb2._ALLOCATIONDESCRIPTION
_NODEEXECSTATS.fields_by_name['memory_stats'].message_type = _MEMORYSTATS
_DEVICESTEPSTATS_THREADNAMESENTRY.containing_type = _DEVICESTEPSTATS
_DEVICESTEPSTATS.fields_by_name['node_stats'].message_type = _NODEEXECSTATS
_DEVICESTEPSTATS.fields_by_name['thread_names'].message_type = _DEVICESTEPSTATS_THREADNAMESENTRY
_STEPSTATS.fields_by_name['dev_stats'].message_type = _DEVICESTEPSTATS
DESCRIPTOR.message_types_by_name['AllocationRecord'] = _ALLOCATIONRECORD
DESCRIPTOR.message_types_by_name['AllocatorMemoryUsed'] = _ALLOCATORMEMORYUSED
DESCRIPTOR.message_types_by_name['NodeOutput'] = _NODEOUTPUT
DESCRIPTOR.message_types_by_name['MemoryStats'] = _MEMORYSTATS
DESCRIPTOR.message_types_by_name['NodeExecStats'] = _NODEEXECSTATS
DESCRIPTOR.message_types_by_name['DeviceStepStats'] = _DEVICESTEPSTATS
DESCRIPTOR.message_types_by_name['StepStats'] = _STEPSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
AllocationRecord = _reflection.GeneratedProtocolMessageType('AllocationRecord', (_message.Message,), {'DESCRIPTOR': _ALLOCATIONRECORD, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(AllocationRecord)
AllocatorMemoryUsed = _reflection.GeneratedProtocolMessageType('AllocatorMemoryUsed', (_message.Message,), {'DESCRIPTOR': _ALLOCATORMEMORYUSED, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(AllocatorMemoryUsed)
NodeOutput = _reflection.GeneratedProtocolMessageType('NodeOutput', (_message.Message,), {'DESCRIPTOR': _NODEOUTPUT, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(NodeOutput)
MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), {'DESCRIPTOR': _MEMORYSTATS, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(MemoryStats)
NodeExecStats = _reflection.GeneratedProtocolMessageType('NodeExecStats', (_message.Message,), {'DESCRIPTOR': _NODEEXECSTATS, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(NodeExecStats)
DeviceStepStats = _reflection.GeneratedProtocolMessageType('DeviceStepStats', (_message.Message,), {'ThreadNamesEntry': _reflection.GeneratedProtocolMessageType('ThreadNamesEntry', (_message.Message,), {'DESCRIPTOR': _DEVICESTEPSTATS_THREADNAMESENTRY, '__module__': 'tensorflow.core.framework.step_stats_pb2'}), 'DESCRIPTOR': _DEVICESTEPSTATS, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(DeviceStepStats)
_sym_db.RegisterMessage(DeviceStepStats.ThreadNamesEntry)
StepStats = _reflection.GeneratedProtocolMessageType('StepStats', (_message.Message,), {'DESCRIPTOR': _STEPSTATS, '__module__': 'tensorflow.core.framework.step_stats_pb2'})
_sym_db.RegisterMessage(StepStats)
DESCRIPTOR._options = None
_MEMORYSTATS.fields_by_name['device_temp_memory_size']._options = None
_MEMORYSTATS.fields_by_name['device_persistent_memory_size']._options = None
_MEMORYSTATS.fields_by_name['device_persistent_tensor_alloc_ids']._options = None
_DEVICESTEPSTATS_THREADNAMESENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import master_pb2 as tensorflow_dot_core_dot_protobuf_dot_master__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/master_service.proto', package='tensorflow.grpc', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\x13MasterServiceProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/protobuf/master_service.proto\x12\x0ftensorflow.grpc\x1a%tensorflow/core/protobuf/master.proto2\xbb\x06\n\rMasterService\x12T\n\rCreateSession\x12 .tensorflow.CreateSessionRequest\x1a!.tensorflow.CreateSessionResponse\x12T\n\rExtendSession\x12 .tensorflow.ExtendSessionRequest\x1a!.tensorflow.ExtendSessionResponse\x12Z\n\x0fPartialRunSetup\x12".tensorflow.PartialRunSetupRequest\x1a#.tensorflow.PartialRunSetupResponse\x12B\n\x07RunStep\x12\x1a.tensorflow.RunStepRequest\x1a\x1b.tensorflow.RunStepResponse\x12Q\n\x0cCloseSession\x12\x1f.tensorflow.CloseSessionRequest\x1a .tensorflow.CloseSessionResponse\x12N\n\x0bListDevices\x12\x1e.tensorflow.ListDevicesRequest\x1a\x1f.tensorflow.ListDevicesResponse\x12<\n\x05Reset\x12\x18.tensorflow.ResetRequest\x1a\x19.tensorflow.ResetResponse\x12Q\n\x0cMakeCallable\x12\x1f.tensorflow.MakeCallableRequest\x1a .tensorflow.MakeCallableResponse\x12N\n\x0bRunCallable\x12\x1e.tensorflow.RunCallableRequest\x1a\x1f.tensorflow.RunCallableResponse\x12Z\n\x0fReleaseCallable\x12".tensorflow.ReleaseCallableRequest\x1a#.tensorflow.ReleaseCallableResponseB\x8a\x01\n\x1aorg.tensorflow.distruntimeB\x13MasterServiceProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_master__pb2.DESCRIPTOR])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DESCRIPTOR._options = None
_MASTERSERVICE = _descriptor.ServiceDescriptor(name='MasterService', full_name='tensorflow.grpc.MasterService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=106, serialized_end=933, methods=[_descriptor.MethodDescriptor(name='CreateSession', full_name='tensorflow.grpc.MasterService.CreateSession', index=0, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._CREATESESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._CREATESESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ExtendSession', full_name='tensorflow.grpc.MasterService.ExtendSession', index=1, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._EXTENDSESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._EXTENDSESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='PartialRunSetup', full_name='tensorflow.grpc.MasterService.PartialRunSetup', index=2, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._PARTIALRUNSETUPREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._PARTIALRUNSETUPRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RunStep', full_name='tensorflow.grpc.MasterService.RunStep', index=3, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNSTEPREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNSTEPRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CloseSession', full_name='tensorflow.grpc.MasterService.CloseSession', index=4, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._CLOSESESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._CLOSESESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ListDevices', full_name='tensorflow.grpc.MasterService.ListDevices', index=5, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._LISTDEVICESREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._LISTDEVICESRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Reset', full_name='tensorflow.grpc.MasterService.Reset', index=6, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RESETREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RESETRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='MakeCallable', full_name='tensorflow.grpc.MasterService.MakeCallable', index=7, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._MAKECALLABLEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._MAKECALLABLERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RunCallable', full_name='tensorflow.grpc.MasterService.RunCallable', index=8, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNCALLABLEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNCALLABLERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ReleaseCallable', full_name='tensorflow.grpc.MasterService.ReleaseCallable', index=9, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RELEASECALLABLEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_master__pb2._RELEASECALLABLERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_MASTERSERVICE)
DESCRIPTOR.services_by_name['MasterService'] = _MASTERSERVICE




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/control_flow.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x11ControlFlowProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n+tensorflow/core/protobuf/control_flow.proto\x12\ntensorflow"\x96\x01\n\tValuesDef\x12\x0e\n\x06values\x18\x01 \x03(\t\x12B\n\x0fexternal_values\x18\x02 \x03(\x0b2).tensorflow.ValuesDef.ExternalValuesEntry\x1a5\n\x13ExternalValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"\x83\x01\n\x15ControlFlowContextDef\x12/\n\tcond_ctxt\x18\x01 \x01(\x0b2\x1a.tensorflow.CondContextDefH\x00\x121\n\nwhile_ctxt\x18\x02 \x01(\x0b2\x1b.tensorflow.WhileContextDefH\x00B\x06\n\x04ctxt"\xc4\x01\n\x0eCondContextDef\x12\x14\n\x0ccontext_name\x18\x01 \x01(\t\x12\x11\n\tpred_name\x18\x02 \x01(\t\x12\x12\n\npivot_name\x18\x03 \x01(\t\x12\x0e\n\x06branch\x18\x04 \x01(\x05\x12)\n\nvalues_def\x18\x05 \x01(\x0b2\x15.tensorflow.ValuesDef\x12:\n\x0fnested_contexts\x18\x06 \x03(\x0b2!.tensorflow.ControlFlowContextDef"\xf5\x02\n\x0fWhileContextDef\x12\x14\n\x0ccontext_name\x18\x01 \x01(\t\x12\x1b\n\x13parallel_iterations\x18\x02 \x01(\x05\x12\x11\n\tback_prop\x18\x03 \x01(\x08\x12\x13\n\x0bswap_memory\x18\x04 \x01(\x08\x12\x12\n\npivot_name\x18\x05 \x01(\t\x12\x1b\n\x13pivot_for_pred_name\x18\x06 \x01(\t\x12\x1b\n\x13pivot_for_body_name\x18\x07 \x01(\t\x12\x17\n\x0floop_exit_names\x18\x08 \x03(\t\x12\x18\n\x10loop_enter_names\x18\n \x03(\t\x12)\n\nvalues_def\x18\t \x01(\x0b2\x15.tensorflow.ValuesDef\x12\x1f\n\x17maximum_iterations_name\x18\x0b \x01(\t\x12:\n\x0fnested_contexts\x18\x0c \x03(\x0b2!.tensorflow.ControlFlowContextDefB\x89\x01\n\x18org.tensorflow.frameworkB\x11ControlFlowProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3')
_VALUESDEF_EXTERNALVALUESENTRY = _descriptor.Descriptor(name='ExternalValuesEntry', full_name='tensorflow.ValuesDef.ExternalValuesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.ValuesDef.ExternalValuesEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.ValuesDef.ExternalValuesEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=157, serialized_end=210)
_VALUESDEF = _descriptor.Descriptor(name='ValuesDef', full_name='tensorflow.ValuesDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='values', full_name='tensorflow.ValuesDef.values', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='external_values', full_name='tensorflow.ValuesDef.external_values', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_VALUESDEF_EXTERNALVALUESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=60, serialized_end=210)
_CONTROLFLOWCONTEXTDEF = _descriptor.Descriptor(name='ControlFlowContextDef', full_name='tensorflow.ControlFlowContextDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cond_ctxt', full_name='tensorflow.ControlFlowContextDef.cond_ctxt', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='while_ctxt', full_name='tensorflow.ControlFlowContextDef.while_ctxt', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='ctxt', full_name='tensorflow.ControlFlowContextDef.ctxt', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=213, serialized_end=344)
_CONDCONTEXTDEF = _descriptor.Descriptor(name='CondContextDef', full_name='tensorflow.CondContextDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_name', full_name='tensorflow.CondContextDef.context_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pred_name', full_name='tensorflow.CondContextDef.pred_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pivot_name', full_name='tensorflow.CondContextDef.pivot_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='branch', full_name='tensorflow.CondContextDef.branch', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='values_def', full_name='tensorflow.CondContextDef.values_def', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='nested_contexts', full_name='tensorflow.CondContextDef.nested_contexts', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=347, serialized_end=543)
_WHILECONTEXTDEF = _descriptor.Descriptor(name='WhileContextDef', full_name='tensorflow.WhileContextDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_name', full_name='tensorflow.WhileContextDef.context_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parallel_iterations', full_name='tensorflow.WhileContextDef.parallel_iterations', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='back_prop', full_name='tensorflow.WhileContextDef.back_prop', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='swap_memory', full_name='tensorflow.WhileContextDef.swap_memory', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pivot_name', full_name='tensorflow.WhileContextDef.pivot_name', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pivot_for_pred_name', full_name='tensorflow.WhileContextDef.pivot_for_pred_name', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pivot_for_body_name', full_name='tensorflow.WhileContextDef.pivot_for_body_name', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='loop_exit_names', full_name='tensorflow.WhileContextDef.loop_exit_names', index=7, number=8, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='loop_enter_names', full_name='tensorflow.WhileContextDef.loop_enter_names', index=8, number=10, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='values_def', full_name='tensorflow.WhileContextDef.values_def', index=9, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='maximum_iterations_name', full_name='tensorflow.WhileContextDef.maximum_iterations_name', index=10, number=11, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='nested_contexts', full_name='tensorflow.WhileContextDef.nested_contexts', index=11, number=12, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=546, serialized_end=919)
_VALUESDEF_EXTERNALVALUESENTRY.containing_type = _VALUESDEF
_VALUESDEF.fields_by_name['external_values'].message_type = _VALUESDEF_EXTERNALVALUESENTRY
_CONTROLFLOWCONTEXTDEF.fields_by_name['cond_ctxt'].message_type = _CONDCONTEXTDEF
_CONTROLFLOWCONTEXTDEF.fields_by_name['while_ctxt'].message_type = _WHILECONTEXTDEF
_CONTROLFLOWCONTEXTDEF.oneofs_by_name['ctxt'].fields.append(_CONTROLFLOWCONTEXTDEF.fields_by_name['cond_ctxt'])
_CONTROLFLOWCONTEXTDEF.fields_by_name['cond_ctxt'].containing_oneof = _CONTROLFLOWCONTEXTDEF.oneofs_by_name['ctxt']
_CONTROLFLOWCONTEXTDEF.oneofs_by_name['ctxt'].fields.append(_CONTROLFLOWCONTEXTDEF.fields_by_name['while_ctxt'])
_CONTROLFLOWCONTEXTDEF.fields_by_name['while_ctxt'].containing_oneof = _CONTROLFLOWCONTEXTDEF.oneofs_by_name['ctxt']
_CONDCONTEXTDEF.fields_by_name['values_def'].message_type = _VALUESDEF
_CONDCONTEXTDEF.fields_by_name['nested_contexts'].message_type = _CONTROLFLOWCONTEXTDEF
_WHILECONTEXTDEF.fields_by_name['values_def'].message_type = _VALUESDEF
_WHILECONTEXTDEF.fields_by_name['nested_contexts'].message_type = _CONTROLFLOWCONTEXTDEF
DESCRIPTOR.message_types_by_name['ValuesDef'] = _VALUESDEF
DESCRIPTOR.message_types_by_name['ControlFlowContextDef'] = _CONTROLFLOWCONTEXTDEF
DESCRIPTOR.message_types_by_name['CondContextDef'] = _CONDCONTEXTDEF
DESCRIPTOR.message_types_by_name['WhileContextDef'] = _WHILECONTEXTDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ValuesDef = _reflection.GeneratedProtocolMessageType('ValuesDef', (_message.Message,), {'ExternalValuesEntry': _reflection.GeneratedProtocolMessageType('ExternalValuesEntry', (_message.Message,), {'DESCRIPTOR': _VALUESDEF_EXTERNALVALUESENTRY, '__module__': 'tensorflow.core.protobuf.control_flow_pb2'}), 'DESCRIPTOR': _VALUESDEF, '__module__': 'tensorflow.core.protobuf.control_flow_pb2'})
_sym_db.RegisterMessage(ValuesDef)
_sym_db.RegisterMessage(ValuesDef.ExternalValuesEntry)
ControlFlowContextDef = _reflection.GeneratedProtocolMessageType('ControlFlowContextDef', (_message.Message,), {'DESCRIPTOR': _CONTROLFLOWCONTEXTDEF, '__module__': 'tensorflow.core.protobuf.control_flow_pb2'})
_sym_db.RegisterMessage(ControlFlowContextDef)
CondContextDef = _reflection.GeneratedProtocolMessageType('CondContextDef', (_message.Message,), {'DESCRIPTOR': _CONDCONTEXTDEF, '__module__': 'tensorflow.core.protobuf.control_flow_pb2'})
_sym_db.RegisterMessage(CondContextDef)
WhileContextDef = _reflection.GeneratedProtocolMessageType('WhileContextDef', (_message.Message,), {'DESCRIPTOR': _WHILECONTEXTDEF, '__module__': 'tensorflow.core.protobuf.control_flow_pb2'})
_sym_db.RegisterMessage(WhileContextDef)
DESCRIPTOR._options = None
_VALUESDEF_EXTERNALVALUESENTRY._options = None



import platform as _platform

# # https://stackoverflow.com/questions/1325581/how-do-i-check-if-im-running-on-windows-in-python
# def is_windows_platform() -> bool:
#   return _os.name == 'nt'

def is_windows_platform() -> bool:
  return _platform.system() == "Windows"

def is_apple_platform() -> bool:
  return _platform.system() == "Darwin"

def is_freebsd_platform() -> bool:
  return _platform.system() == "FreeBSD"

def is_iphone_platform() -> bool:
  return False  # TODO: Does Python run on iOS?

def is_haiku_platform() -> bool:
  return _platform.system() == "Haiku"  # TODO: Is this correct?
